@@ -43,18 +43,21 @@
 #include "gpm-stock-icons.h"
 #include "gpm-brightness.h"
 #include "gpm-hal.h"
+#include "gpm-marshal.h"
 
 #define DIM_INTERVAL		10 /* ms */
 
-static void     gpm_brightness_class_init (GpmBrightnessClass *klass);
-static void     gpm_brightness_init       (GpmBrightness      *brightness);
-static void     gpm_brightness_finalize   (GObject	      *object);
+static void	gpm_brightness_class_init (GpmBrightnessClass *klass);
+static void	gpm_brightness_init	  (GpmBrightness      *brightness);
+static void	gpm_brightness_finalize	  (GObject	      *object);
+static gboolean	gpm_brightness_level_update_hw (GpmBrightness *brightness);
+static int	gpm_brightness_hw_to_percent (int hw, int levels);
 
 #define GPM_BRIGHTNESS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BRIGHTNESS, GpmBrightnessPrivate))
 
 struct GpmBrightnessPrivate
 {
-	gboolean	    has_hardware;
+	gboolean    has_hardware;
 	int	    current_hw;
 	int	    saved_value_hw;
 	int	    levels;
@@ -62,42 +65,21 @@ struct GpmBrightnessPrivate
 	DBusGProxy *proxy;
 };
 
-static GObjectClass *parent_class = NULL;
+enum {
+	BRIGHTNESS_STEP_CHANGED,
+	LAST_SIGNAL
+};
+
+static guint	     signals [LAST_SIGNAL] = { 0, };
 
 G_DEFINE_TYPE (GpmBrightness, gpm_brightness, G_TYPE_OBJECT)
 
-static gboolean
-gpm_brightness_level_update_hw (GpmBrightness *brightness);
-
-static void
-gpm_brightness_set_property (GObject		  *object,
-			     guint		   prop_id,
-			     const GValue	  *value,
-			     GParamSpec		  *pspec)
-{
-	switch (prop_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
-static void
-gpm_brightness_get_property (GObject		  *object,
-			     guint		   prop_id,
-			     GValue		  *value,
-			     GParamSpec		  *pspec)
-{
-	switch (prop_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
+/**
+ * gpm_brightness_constructor:
+ **/
 static GObject *
-gpm_brightness_constructor (GType                  type,
-			    guint                  n_construct_properties,
+gpm_brightness_constructor (GType		  type,
+			    guint		  n_construct_properties,
 			    GObjectConstructParam *construct_properties)
 {
 	GpmBrightness      *brightness;
@@ -108,23 +90,42 @@ gpm_brightness_constructor (GType                  type,
 	return G_OBJECT (brightness);
 }
 
+/**
+ * gpm_brightness_class_init:
+ **/
 static void
 gpm_brightness_class_init (GpmBrightnessClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	parent_class = g_type_class_peek_parent (klass);
 	object_class->finalize	   = gpm_brightness_finalize;
-	object_class->get_property = gpm_brightness_get_property;
-	object_class->set_property = gpm_brightness_set_property;
 	object_class->constructor  = gpm_brightness_constructor;
+
 	g_type_class_add_private (klass, sizeof (GpmBrightnessPrivate));
+
+	signals [BRIGHTNESS_STEP_CHANGED] =
+		g_signal_new ("brightness-step-changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GpmBrightnessClass, lcd_step_changed),
+			      NULL,
+			      NULL,
+			      gpm_marshal_VOID__INT,
+			      G_TYPE_NONE, 1, G_TYPE_INT);
 }
 
+/**
+ * gpm_brightness_init:
+ * @brightness: This brightness class instance
+ *
+ * initialises the brightness class. NOTE: We expect laptop_panel objects
+ * to *NOT* be removed or added during the session.
+ * We only control the first laptop_panel object if there are more than one.
+ **/
 static void
 gpm_brightness_init (GpmBrightness *brightness)
 {
 	DBusGConnection *system_connection = NULL;
-	gchar          **names;
+	gchar	  **names;
 
 	brightness->priv = GPM_BRIGHTNESS_GET_PRIVATE (brightness);
 
@@ -137,6 +138,7 @@ gpm_brightness_init (GpmBrightness *brightness)
 	}
 
 	brightness->priv->has_hardware = TRUE;
+
 	/* We only want first laptop_panel object (should only be one) */
 	brightness->priv->udi = g_strdup (names[0]);
 	gpm_hal_free_capability (names);
@@ -162,6 +164,9 @@ gpm_brightness_init (GpmBrightness *brightness)
 		   brightness->priv->levels - 1);
 }
 
+/**
+ * gpm_brightness_finalize:
+ **/
 static void
 gpm_brightness_finalize (GObject *object)
 {
@@ -174,9 +179,13 @@ gpm_brightness_finalize (GObject *object)
 	g_object_unref (G_OBJECT (brightness->priv->proxy));
 
 	g_return_if_fail (brightness->priv != NULL);
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gpm_brightness_parent_class)->finalize (object);
 }
 
+/**
+ * gpm_brightness_new:
+ * Return value: A new brightness class instance.
+ **/
 GpmBrightness *
 gpm_brightness_new (void)
 {
@@ -185,7 +194,14 @@ gpm_brightness_new (void)
 	return GPM_BRIGHTNESS (brightness);
 }
 
-/* updates the value of brightness_level_hw as it may have changed on some h/w */
+/**
+ * gpm_brightness_level_update_hw:
+ * @brightness: This brightness class instance
+ *
+ * Updates the private local value of brightness_level_hw as it may have
+ * changed on some h/w
+ * Return value: Success.
+ **/
 static gboolean
 gpm_brightness_level_update_hw (GpmBrightness *brightness)
 {
@@ -208,7 +224,15 @@ gpm_brightness_level_update_hw (GpmBrightness *brightness)
 	return retval;
 }
 
-
+/**
+ * gpm_brightness_level_set_hw:
+ * @brightness: This brightness class instance
+ * @brightness_level_hw: The hardware level in raw units
+ *
+ * Sets the hardware value to a new number.
+ *
+ * Return value: Success.
+ **/
 static gboolean
 gpm_brightness_level_set_hw (GpmBrightness *brightness,
 			     int	    brightness_level_hw)
@@ -244,26 +268,57 @@ gpm_brightness_level_set_hw (GpmBrightness *brightness,
 	return retval;
 }
 
+/**
+ * gpm_brightness_level_up:
+ * @brightness: This brightness class instance
+ *
+ * If possible, put the brightness of the LCD up one unit.
+ **/
 void
 gpm_brightness_level_up (GpmBrightness *brightness)
 {
 	if (! brightness->priv->has_hardware) {
 		return;
 	}
-	int current_hw = brightness->priv->current_hw;
-	gpm_brightness_level_set_hw (brightness, current_hw + 1);
+	gpm_brightness_level_set_hw (brightness, brightness->priv->current_hw + 1);
+
+	int percentage;
+	percentage = gpm_brightness_hw_to_percent (brightness->priv->current_hw,
+						   brightness->priv->levels);
+	gpm_debug ("emitting brightness-step-changed : %i", percentage);
+	g_signal_emit (brightness, signals [BRIGHTNESS_STEP_CHANGED], 0, percentage);
 }
 
+/**
+ * gpm_brightness_level_down:
+ * @brightness: This brightness class instance
+ *
+ * If possible, put the brightness of the LCD down one unit.
+ **/
 void
 gpm_brightness_level_down (GpmBrightness *brightness)
 {
 	if (! brightness->priv->has_hardware) {
 		return;
 	}
-	int current_hw = brightness->priv->current_hw;
-	gpm_brightness_level_set_hw (brightness, current_hw - 1);
+	gpm_brightness_level_set_hw (brightness, brightness->priv->current_hw - 1);
+	int percentage;
+	percentage = gpm_brightness_hw_to_percent (brightness->priv->current_hw,
+						   brightness->priv->levels);
+	gpm_debug ("emitting brightness-step-changed : %i", percentage);
+	g_signal_emit (brightness, signals [BRIGHTNESS_STEP_CHANGED], 0, percentage);
 }
 
+/**
+ * gpm_brightness_percent_to_hw:
+ * @percentage: The percentage to convert
+ * @levels: The number of hardware levels for our hardware
+ *
+ * We have to be carefull when converting from %->hw as precision is very
+ * important if we want the highest value.
+ *
+ * Return value: The hardware value for this percentage.
+ **/
 static int
 gpm_brightness_percent_to_hw (int percentage,
 			      int levels)
@@ -277,10 +332,36 @@ gpm_brightness_percent_to_hw (int percentage,
 	return ( (float) percentage * (float) (levels - 1)) / 100.0f;
 }
 
-/* brightness_level is a percentage */
+/**
+ * gpm_brightness_hw_to_percent:
+ * @hw: The hardware level
+ * @levels: The number of hardware levels for our hardware
+ *
+ * We have to be carefull when converting from hw->%.
+ *
+ * Return value: The percentage for this hardware value.
+ **/
+static int
+gpm_brightness_hw_to_percent (int hw,
+			      int levels)
+{
+	/* check we are in range */
+	if (hw < 0) {
+		return 0;
+	} else if (hw > levels) {
+		return 100;
+	}
+	return (int) ((float) hw * (100.0f / (float) (levels - 1)));
+}
+
+/**
+ * gpm_brightness_level_set:
+ * @brightness: This brightness class instance
+ * @brightness_level: The percentage brightness
+ **/
 void
 gpm_brightness_level_set (GpmBrightness *brightness,
-			  int            brightness_level)
+			  int		 brightness_level)
 {
 	int brightness_level_hw;
 	int levels;
@@ -296,10 +377,34 @@ gpm_brightness_level_set (GpmBrightness *brightness,
 	}
 }
 
-/* new_level_hw is raw value */
+/**
+ * gpm_brightness_level_get:
+ * @brightness: This brightness class instance
+ * Return value: The percentage brightness, or -1 for no hardware
+ *
+ * Gets the current (or at least what this class thinks is current) percentage
+ * brightness. This is quick as no HAL inquiry is done.
+ **/
+int
+gpm_brightness_level_get (GpmBrightness *brightness)
+{
+	int percentage;
+	if (! brightness->priv->has_hardware) {
+		return -1;
+	}
+	percentage = gpm_brightness_hw_to_percent (brightness->priv->current_hw,
+						   brightness->priv->levels);
+	return percentage;
+}
+
+/**
+ * gpm_brightness_level_dim_hw:
+ * @brightness: This brightness class instance
+ * @new_level_hw: The new hardware level
+ **/
 static void
 gpm_brightness_level_dim_hw (GpmBrightness *brightness,
-			     int            new_level_hw)
+			     int	    new_level_hw)
 {
 	int   current_hw;
 	int   a;
@@ -325,10 +430,16 @@ gpm_brightness_level_dim_hw (GpmBrightness *brightness,
 	}
 }
 
-/* brightness_level is a percentage */
+/**
+ * gpm_brightness_level_dim:
+ * @brightness: This brightness class instance
+ * @brightness_level: The new percentage brightness
+ *
+ * Dims the screen slowly to the new value, if we are not an IBM.
+ **/
 void
 gpm_brightness_level_dim (GpmBrightness *brightness,
-			  int            brightness_level)
+			  int		 brightness_level)
 {
 	char *manufacturer_string = NULL;
 	int   new_level_hw;
@@ -355,13 +466,20 @@ gpm_brightness_level_dim (GpmBrightness *brightness,
 	gpm_brightness_level_dim_hw (brightness, new_level_hw);
 }
 
-/* same as gpm_brightness_level_dim, but saves value for resume */
+/**
+ * gpm_brightness_level_save:
+ * @brightness: This brightness class instance
+ * @brightness_level: The new brightness level
+ *
+ * Saves the current brightness, and then sets the new brightness to the value
+ * specified in brightness_level using the dimming function.
+ **/
 void
 gpm_brightness_level_save (GpmBrightness *brightness,
-			   int            brightness_level)
+			   int		  brightness_level)
 {
 	int   new_level_hw;
-	
+
 	gpm_debug ("Saving and setting brightness to %i%%", brightness_level);
 	brightness->priv->saved_value_hw = brightness->priv->current_hw;
 
@@ -370,6 +488,12 @@ gpm_brightness_level_save (GpmBrightness *brightness,
 	gpm_brightness_level_dim_hw (brightness, new_level_hw);
 }
 
+/**
+ * gpm_brightness_level_resume:
+ * @brightness: This brightness class instance
+ *
+ * Restores the brightness to that saved by gpm_brightness_level_save()
+ **/
 void
 gpm_brightness_level_resume (GpmBrightness *brightness)
 {
