@@ -90,7 +90,6 @@ gpm_hal_is_on_ac (void)
 	return is_on_ac;
 }
 
-
 /** Returns true if system.formfactor == "laptop"
  *
  *  @return			TRUE is computer is identified as a laptop
@@ -174,6 +173,33 @@ gpm_hal_can_hibernate (void)
 	return can_hibernate;
 }
 
+/* we have to be clever, as hal can pass back two types of errors, and we have
+   to ignore dbus timeouts */
+static gboolean
+gpm_hal_handle_error (guint ret, GError *error, const char *method)
+{
+	gboolean retval = TRUE;
+	if (error) {
+		/* DBUS might time out, which is okay. We can remove this code
+		   when the dbus glib bindings are fixed. See #332888 */
+		if (g_error_matches (error, DBUS_GERROR, DBUS_GERROR_NO_REPLY)) {
+			gpm_debug ("DBUS timed out, but recovering");
+			retval = TRUE;
+		} else {
+			gpm_warning ("%s failed\n(%s)",
+				     method,
+				     error->message);
+			retval = FALSE;
+		}
+		g_error_free (error);
+	} else if (ret != 0) {
+		/* we might not get an error set */
+		gpm_warning ("%s failed (Unknown error)", method);
+		retval = FALSE;
+	}
+	return retval;
+}
+
 /** Uses org.freedesktop.Hal.Device.SystemPowerManagement.Suspend ()
  *
  *  @param	wakeup		Seconds to wakeup, currently unsupported
@@ -182,7 +208,7 @@ gpm_hal_can_hibernate (void)
 gboolean
 gpm_hal_suspend (gint wakeup)
 {
-	gint ret;
+	guint ret = 0;
 	DBusGConnection *system_connection = NULL;
 	DBusGProxy *hal_proxy = NULL;
 	GError *error = NULL;
@@ -195,18 +221,11 @@ gpm_hal_suspend (gint wakeup)
 					       HAL_ROOT_COMPUTER,
 					       HAL_DBUS_INTERFACE_POWER);
 	retval = TRUE;
-	if (!dbus_g_proxy_call (hal_proxy, "Suspend", &error,
-			G_TYPE_INT, wakeup, G_TYPE_INVALID,
-			G_TYPE_UINT, &ret, G_TYPE_INVALID)) {
-		if (error) {
-			gpm_warning ("%s", error->message);
-			g_error_free (error);
-		}
-		gpm_warning (HAL_DBUS_INTERFACE_POWER ".Suspend failed (HAL error)");
-		retval = FALSE;
-	}
-	if (ret != 0)
-		retval = FALSE;
+	dbus_g_proxy_call (hal_proxy, "Suspend", &error,
+			   G_TYPE_INT, wakeup, G_TYPE_INVALID,
+			   G_TYPE_UINT, &ret, G_TYPE_INVALID);
+	retval = gpm_hal_handle_error (ret, error, "suspend");
+
 	g_object_unref (G_OBJECT (hal_proxy));
 	return retval;
 }
@@ -220,7 +239,7 @@ gpm_hal_suspend (gint wakeup)
 static gboolean
 hal_pm_method_void (const gchar* method)
 {
-	gint ret;
+	guint ret = 0;
 	DBusGConnection *system_connection = NULL;
 	DBusGProxy *hal_proxy = NULL;
 	GError *error = NULL;
@@ -233,19 +252,11 @@ hal_pm_method_void (const gchar* method)
 					       HAL_ROOT_COMPUTER,
 					       HAL_DBUS_INTERFACE_POWER);
 	retval = TRUE;
-	if (!dbus_g_proxy_call (hal_proxy, method, &error,
-			G_TYPE_INVALID,
-			G_TYPE_UINT, &ret, G_TYPE_INVALID)) {
-		if (error) {
-			gpm_warning ("%s", error->message);
-			g_error_free (error);
-		}
-		gpm_warning (HAL_DBUS_INTERFACE_POWER
-			   ".%s failed (HAL error)", method);
-		retval = FALSE;
-	}
-	if (ret != 0)
-		retval = FALSE;
+	dbus_g_proxy_call (hal_proxy, method, &error,
+			   G_TYPE_INVALID,
+			   G_TYPE_UINT, &ret, G_TYPE_INVALID);
+	retval = gpm_hal_handle_error (ret, error, method);
+
 	g_object_unref (G_OBJECT (hal_proxy));
 	return retval;
 }
@@ -298,18 +309,11 @@ gpm_hal_enable_power_save (gboolean enable)
 					       HAL_ROOT_COMPUTER,
 					       HAL_DBUS_INTERFACE_POWER);
 	retval = TRUE;
-	if (!dbus_g_proxy_call (hal_proxy, "SetPowerSave", &error,
-			G_TYPE_BOOLEAN, enable, G_TYPE_INVALID,
-			G_TYPE_UINT, &ret, G_TYPE_INVALID)) {
-		if (error) {
-			gpm_warning ("%s", error->message);
-			g_error_free (error);
-		}
-		gpm_debug (HAL_DBUS_INTERFACE_POWER ".SetPowerSave failed (HAL error)");
-		retval = FALSE;
-	}
-	if (ret != 0)
-		retval = FALSE;
+	dbus_g_proxy_call (hal_proxy, "SetPowerSave", &error,
+			   G_TYPE_BOOLEAN, enable, G_TYPE_INVALID,
+			   G_TYPE_UINT, &ret, G_TYPE_INVALID);
+	retval = gpm_hal_handle_error (ret, error, "power save");
+
 	g_object_unref (G_OBJECT (hal_proxy));
 	return retval;
 }
@@ -340,7 +344,7 @@ gpm_hal_device_get_bool (const gchar *udi, const gchar *key, gboolean *value)
 				G_TYPE_STRING, key, G_TYPE_INVALID,
 				G_TYPE_BOOLEAN, value, G_TYPE_INVALID)) {
 		if (error) {
-			gpm_debug ("Error: %s", error->message);
+			gpm_debug ("%s", error->message);
 			g_error_free (error);
 		}
 		*value = FALSE;
@@ -378,7 +382,7 @@ gpm_hal_device_get_string (const gchar *udi, const gchar *key, gchar **value)
 				G_TYPE_STRING, key, G_TYPE_INVALID,
 				G_TYPE_STRING, value, G_TYPE_INVALID)) {
 		if (error) {
-			gpm_debug ("Error: %s", error->message);
+			gpm_debug ("%s", error->message);
 			g_error_free (error);
 		}
 		*value = NULL;
@@ -414,7 +418,7 @@ gpm_hal_device_get_int (const gchar *udi, const gchar *key, gint *value)
 				G_TYPE_STRING, key, G_TYPE_INVALID,
 				G_TYPE_INT, value, G_TYPE_INVALID)) {
 		if (error) {
-			gpm_debug ("Error: %s", error->message);
+			gpm_debug ("%s", error->message);
 			g_error_free (error);
 		}
 		*value = 0;
@@ -449,7 +453,7 @@ gpm_hal_find_device_capability (const gchar *capability, gchar ***value)
 				G_TYPE_STRING, capability, G_TYPE_INVALID,
 				G_TYPE_STRV, value, G_TYPE_INVALID)) {
 		if (error) {
-			gpm_debug ("Error: %s", error->message);
+			gpm_debug ("%s", error->message);
 			g_error_free (error);
 		}
 		*value = NULL;
@@ -518,10 +522,12 @@ gpm_hal_num_devices_of_capability_with_value (const gchar *capability,
 	for (i = 0; names[i]; i++) {
 		gchar *type = NULL;
 		gpm_hal_device_get_string (names[i], key, &type);
-		if (strcmp (type, value) == 0)
-			valid++;
-		g_free (type);
-	};
+		if (type != NULL) {
+			if (strcmp (type, value) == 0)
+				valid++;
+			g_free (type);
+		}
+	}
 	gpm_hal_free_capability (names);
 	gpm_debug ("%i devices of capability %s where %s is %s",
 		   valid, capability, key, value);
