@@ -52,7 +52,7 @@
 
 static void     gpm_tray_icon_class_init (GpmTrayIconClass *klass);
 static void     gpm_tray_icon_init       (GpmTrayIcon      *tray_icon);
-static void     gpm_tray_icon_finalize   (GObject          *object);
+static void     gpm_tray_icon_finalize   (GObject	   *object);
 
 #define GPM_TRAY_ICON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_TRAY_ICON, GpmTrayIconPrivate))
 
@@ -65,11 +65,11 @@ struct GpmTrayIconPrivate
 	GtkWidget      *image;
 	GtkWidget      *ebox;
 
-	gboolean        show_notifications;
-	gboolean        is_visible;
+	gboolean	show_notifications;
+	gboolean	is_visible;
 
-	gboolean        can_suspend;
-	gboolean        can_hibernate;
+	gboolean	can_suspend;
+	gboolean	can_hibernate;
 
 #ifdef HAVE_LIBNOTIFY
 	NotifyNotification *notify;
@@ -112,7 +112,7 @@ static GtkActionEntry gpm_tray_icon_action_entries [] =
 };
 static guint gpm_tray_icon_n_action_entries = G_N_ELEMENTS (gpm_tray_icon_action_entries);
 
-static guint         signals [LAST_SIGNAL] = { 0, };
+static guint	 signals [LAST_SIGNAL] = { 0, };
 
 G_DEFINE_TYPE (GpmTrayIcon, gpm_tray_icon, EGG_TYPE_TRAY_ICON)
 
@@ -131,7 +131,6 @@ gpm_tray_icon_enable_suspend (GpmTrayIcon *icon,
 		GtkAction *action;
 
 		icon->priv->can_suspend = enabled;
-
 		action = gtk_action_group_get_action (icon->priv->actiongroup,
 						      "TraySuspend");
 		gtk_action_set_visible (GTK_ACTION (action),
@@ -154,7 +153,6 @@ gpm_tray_icon_enable_hibernate (GpmTrayIcon *icon,
 		GtkAction *action;
 
 		icon->priv->can_hibernate = enabled;
-
 		action = gtk_action_group_get_action (icon->priv->actiongroup,
 						      "TrayHibernate");
 		gtk_action_set_visible (GTK_ACTION (action),
@@ -183,7 +181,7 @@ gpm_tray_icon_set_tooltip (GpmTrayIcon *icon,
 /**
  * gpm_tray_icon_set_image_from_stock:
  * @icon: This TrayIcon class instance
- * @stock_id: The icon name, e.g. GPM_STOCK_APP_ICON
+ * @stock_id: The icon name, e.g. GPM_STOCK_APP_ICON, or NULL to remove.
  *
  * Loads a pixmap from disk, and sets as the tooltip icon
  **/
@@ -195,22 +193,11 @@ gpm_tray_icon_set_image_from_stock (GpmTrayIcon *icon,
 	gpm_debug ("Setting icon to %s", stock_id);
 
 	if (stock_id) {
-		GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
-		GdkPixbuf *pixbuf;
-		pixbuf = gtk_icon_theme_load_icon (icon_theme, stock_id, 24, 0, NULL);
-		if (! pixbuf) {
-			gpm_critical_error ("Cannot find the file %s.\n"
-					    "possibly there is a packaging bug in g-p-m.",
-					    stock_id);
-		}
-		gtk_image_set_from_pixbuf (GTK_IMAGE (icon->priv->image), pixbuf );
-		g_object_unref (pixbuf);
-
+		gtk_image_set_from_icon_name (GTK_IMAGE (icon->priv->image),
+					      stock_id,
+					      GTK_ICON_SIZE_LARGE_TOOLBAR);
 	} else {
-		/* FIXME: gtk_image_clear requires gtk 2.8, so until we
-		 * depend on more then 2.6 (required for FC4) we have to
-		 * comment it out
-		gtk_image_clear (GTK_IMAGE (icon->priv->image));*/
+		gtk_image_clear (GTK_IMAGE (icon->priv->image));
 		if (GTK_WIDGET_VISIBLE (icon->priv->image)) {
 			gtk_widget_queue_resize (GTK_WIDGET (icon->priv->image));
 		}
@@ -309,6 +296,7 @@ gpm_tray_icon_show_about_cb (GtkAction   *action,
 		NULL};
 	const char *artists[] = {
 		"Diana Fong <dfong@redhat.com>",
+		"Jakub Steiner <jimmac@ximian.com>",
 		NULL};
 	const char *license[] = {
 		N_("Licensed under the GNU General Public License Version 2"),
@@ -326,39 +314,30 @@ gpm_tray_icon_show_about_cb (GtkAction   *action,
 		   "02110-1301, USA.")
 	};
   	const char  *translators = _("translator-credits");
-	char        *license_trans;
-	GdkPixbuf   *pixbuf;
+	char	    *license_trans;
 
-	/*
-	 * Translators comment: put your own name here to appear in the about dialog.
-	 */
+	/* Translators comment: put your own name here to appear in the about dialog. */
   	if (!strcmp (translators, "translator-credits")) {
 		translators = NULL;
 	}
 
-	GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
-	pixbuf = gtk_icon_theme_load_icon (icon_theme, GPM_STOCK_APP_ICON, 48, 0, NULL);
-
 	license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
 				     _(license[2]), "\n\n", _(license[3]), "\n",  NULL);
 
 	gtk_window_set_default_icon_name (GPM_STOCK_APP_ICON);
-
 	gtk_show_about_dialog (NULL,
-		               "name", GPM_NAME,
-		               "version", VERSION,
-		               "copyright", "Copyright \xc2\xa9 2005 Richard Hughes",
-		               "license", license_trans,
-		               "website", GPM_HOMEPAGE_URL,
-		               "comments", GPM_DESCRIPTION,
-		               "authors", authors,
-		               "documenters", documenters,
-		               "artists", artists,
-		               "translator-credits", translators,
-		               "logo", pixbuf,
-		               NULL);
-
-	g_object_unref (pixbuf);
+			       "name", GPM_NAME,
+			       "version", VERSION,
+			       "copyright", "Copyright \xc2\xa9 2005-2006 Richard Hughes",
+			       "license", license_trans,
+			       "website", GPM_HOMEPAGE_URL,
+			       "comments", GPM_DESCRIPTION,
+			       "authors", authors,
+			       "documenters", documenters,
+			       "artists", artists,
+			       "translator-credits", translators,
+			       "logo-icon-name", GPM_STOCK_APP_ICON,
+			       NULL);
 }
 
 /**
@@ -375,8 +354,8 @@ tray_popup_position_menu (GtkMenu  *menu,
 {
 	GtkWidget     *widget;
 	GtkRequisition requisition;
-	gint           menu_xpos;
-	gint           menu_ypos;
+	gint	       menu_xpos;
+	gint	       menu_ypos;
 
 	widget = GTK_WIDGET (user_data);
 
@@ -409,6 +388,8 @@ static void
 gpm_tray_icon_popup_cleared_cd (GtkWidget   *widget,
 				GpmTrayIcon *icon)
 {
+	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
+
 	/* we enable the tooltip as the menu has gone */
 	gtk_tooltips_enable (icon->priv->tooltips);
 }
@@ -453,16 +434,15 @@ static void
 gpm_tray_icon_sync_actions (GpmTrayIcon *icon)
 {
 	GtkAction *action;
+	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
 
 	if (icon->priv->actiongroup != NULL) {
 		action = gtk_action_group_get_action (icon->priv->actiongroup,
 						      "TraySuspend");
-
 		gtk_action_set_visible (GTK_ACTION (action), icon->priv->can_suspend);
 
 		action = gtk_action_group_get_action (icon->priv->actiongroup,
 						      "TrayHibernate");
-
 		gtk_action_set_visible (GTK_ACTION (action), icon->priv->can_hibernate);
 	}
 }
@@ -473,13 +453,13 @@ gpm_tray_icon_sync_actions (GpmTrayIcon *icon)
  * Connects the UI to the tray icon instance
  **/
 static GObject *
-gpm_tray_icon_constructor (GType                  type,
-			   guint                  n_construct_properties,
+gpm_tray_icon_constructor (GType		  type,
+			   guint		  n_construct_properties,
 			   GObjectConstructParam *construct_properties)
 {
 	GpmTrayIcon      *tray;
 	GpmTrayIconClass *klass;
-	GError           *error = NULL;
+	GError		 *error = NULL;
 	GtkWidget	 *widget;
 
 	klass = GPM_TRAY_ICON_CLASS (g_type_class_peek (GPM_TYPE_TRAY_ICON));
@@ -545,34 +525,34 @@ gpm_tray_icon_class_init (GpmTrayIconClass *klass)
 
 	signals [SUSPEND] =
 		g_signal_new ("suspend",
-		              G_TYPE_FROM_CLASS (object_class),
-		              G_SIGNAL_RUN_LAST,
-		              G_STRUCT_OFFSET (GpmTrayIconClass, suspend),
-		              NULL,
-		              NULL,
-		              g_cclosure_marshal_VOID__VOID,
-		              G_TYPE_NONE,
-		              0);
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GpmTrayIconClass, suspend),
+			      NULL,
+			      NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 	signals [HIBERNATE] =
 		g_signal_new ("hibernate",
-		              G_TYPE_FROM_CLASS (object_class),
-		              G_SIGNAL_RUN_LAST,
-		              G_STRUCT_OFFSET (GpmTrayIconClass, hibernate),
-		              NULL,
-		              NULL,
-		              g_cclosure_marshal_VOID__VOID,
-		              G_TYPE_NONE,
-		              0);
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GpmTrayIconClass, hibernate),
+			      NULL,
+			      NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 	signals [SHOW_INFO] =
 		g_signal_new ("show-info",
-		              G_TYPE_FROM_CLASS (object_class),
-		              G_SIGNAL_RUN_LAST,
-		              G_STRUCT_OFFSET (GpmTrayIconClass, hibernate),
-		              NULL,
-		              NULL,
-		              g_cclosure_marshal_VOID__VOID,
-		              G_TYPE_NONE,
-		              0);
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GpmTrayIconClass, hibernate),
+			      NULL,
+			      NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 }
 
 /**
@@ -584,12 +564,13 @@ void
 gpm_tray_icon_show (GpmTrayIcon *icon,
 		    gboolean     enabled)
 {
+	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
+
 	if (enabled) {
 		gtk_widget_show_all (GTK_WIDGET (icon));
 		icon->priv->is_visible = TRUE;
 	} else {
 		gtk_widget_hide_all (GTK_WIDGET (icon));
-		gtk_widget_unrealize (GTK_WIDGET (icon));
 		icon->priv->is_visible = FALSE;
 	}
 }
@@ -615,9 +596,9 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 
 	icon->priv->ebox = gtk_event_box_new ();
 	g_signal_connect_object (G_OBJECT (icon->priv->ebox),
-		                 "button_press_event",
-		                 G_CALLBACK (gpm_tray_icon_button_press_cb),
-		                 icon, 0);
+				 "button_press_event",
+				 G_CALLBACK (gpm_tray_icon_button_press_cb),
+				 icon, 0);
 
 	icon->priv->image = gtk_image_new ();
 
@@ -668,31 +649,6 @@ gpm_tray_icon_new (void)
 }
 
 #ifdef HAVE_LIBNOTIFY
-/**
- * get_widget_position:
- * @widget: The icon widget
- * @x: The returned X co-ordinate
- * @y: The returned Y co-ordinate
- *
- * Gets the position where the libnotify arrow should "point"
- * FIXME: Doesn't work on all orientations...
- **/
-static void
-get_widget_position (GtkWidget *widget,
-		     int       *x,
-		     int       *y)
-{
-	g_assert (widget);
-
-	gdk_window_get_origin (GDK_WINDOW (widget->window), x, y);
-
-	*x += widget->allocation.x;
-	*y += widget->allocation.y;
-	*x += widget->allocation.width / 2;
-	*y += widget->allocation.height;
-
-	gpm_debug ("widget position x=%i, y=%i", *x, *y);
-}
 
 /**
  * notification_closed_cb:
@@ -701,7 +657,7 @@ get_widget_position (GtkWidget *widget,
  **/
 static void
 notification_closed_cb (NotifyNotification *notify,
-			GpmTrayIcon        *icon)
+			GpmTrayIcon	*icon)
 {
 	/* just invalidate the pointer */
 	gpm_debug ("caught notification closed signal");
@@ -728,26 +684,20 @@ libnotify_event (GpmTrayIcon    *icon,
 		 const char	*msgicon,
 		 GpmNotifyLevel	 urgency)
 {
-	int x;
-	int y;
-
 	if (icon->priv->notify != NULL) {
 		notify_notification_close (icon->priv->notify, NULL);
 	}
 
-	icon->priv->notify = notify_notification_new (title,
-						      content,
-						      msgicon,
-						      NULL);
+	/* Point to the center of the icon as per the GNOME HIG, #338638 */
+	GtkWidget *point = NULL;
+	if (icon->priv->is_visible) {
+		point = icon->priv->image;
+	}
+	icon->priv->notify = notify_notification_new (title, content,
+						      msgicon, point);
 
 	notify_notification_set_timeout (icon->priv->notify, timeout * 1000);
 
-	if (icon->priv->is_visible) {
-		get_widget_position (GTK_WIDGET (icon), &x, &y);
-		notify_notification_set_hint_int32 (icon->priv->notify, "x", x);
-		notify_notification_set_hint_int32 (icon->priv->notify, "y", y);
-	}
-
 	if (urgency == GPM_NOTIFY_URGENCY_CRITICAL) {
 		gpm_warning ("libnotify: %s : %s", GPM_NAME, content);
 	} else {
@@ -789,9 +739,6 @@ libnotify_event (GpmTrayIcon    *icon,
 	GtkWidget     *dialog;
 	GtkMessageType msg_type;
 
-	/* assertion checks */
-	g_assert (content);
-
 	if (urgency == GPM_NOTIFY_URGENCY_CRITICAL) {
 		msg_type = GTK_MESSAGE_WARNING;
 	} else {
@@ -845,13 +792,7 @@ gpm_tray_icon_notify (GpmTrayIcon	*icon,
 	}
 
 	gpm_debug ("doing notify: %s", title);
-
-	libnotify_event (icon,
-			 title,
-			 content,
-			 timeout,
-			 msgicon,
-			 urgency);
+	libnotify_event (icon, title, content, timeout, msgicon, urgency);
 }
 
 /**
